@@ -224,13 +224,6 @@ void CalendarApplication::setupActions()
         action->setIcon(QIcon::fromTheme(QStringLiteral("view-task-add")));
     }
 
-    actionName = QLatin1String("options_configure_schedule");
-    if (KAuthorized::authorizeAction(actionName)) {
-        auto action = mCollection->addAction(actionName, this, &CalendarApplication::configureSchedule);
-        action->setText(i18n("Configure Schedule…"));
-        action->setIcon(QIcon::fromTheme(QStringLiteral("view-calendar-month")));
-    }
-
     actionName = QLatin1String("switch_application_language");
     if (KAuthorized::authorizeAction(actionName)) {
         auto action = KStandardAction::switchApplicationLanguage(this, &CalendarApplication::openLanguageSwitcher, this);
@@ -401,7 +394,7 @@ void CalendarApplication::showIncidenceByUid(const QString &uid, const QDateTime
     KCalendarCore::Duration duration(occurrence, incidenceEnd);
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup rColorsConfig(config, "Resources Colors");
+    KConfigGroup rColorsConfig(config, QStringLiteral("Resources Colors"));
     const QStringList colorKeyList = rColorsConfig.keyList();
 
     QColor incidenceColor;
@@ -465,7 +458,7 @@ void CalendarApplication::handleMouseViewNavButtons(const Qt::MouseButton presse
     }
 }
 
-QVector<KActionCollection *> CalendarApplication::actionCollections() const
+QList<KActionCollection *> CalendarApplication::actionCollections() const
 {
     return {mCollection, mSortCollection};
 }
@@ -484,3 +477,5 @@ bool CalendarApplication::showMenubar() const
 #ifndef UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
 #endif
+
+#include "moc_calendarapplication.cpp"
