@@ -83,7 +83,7 @@ private:
 
     QTimer mRefreshTimer;
     IncidenceOccurrenceModel *mSourceModel{nullptr};
-    QVector<QVariantList> m_laidOutLines;
+    QList<QVariantList> m_laidOutLines;
     int mPeriodLength{15}; // In minutes
     HourlyIncidenceModel::Filters m_filters;
     bool m_showTodos = true;
