@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
-
+#pragma once
 #include <abstractapplication.h>
 class QQuickWindow;
 class ContactApplication : public AbstractApplication
@@ -10,7 +10,7 @@ class ContactApplication : public AbstractApplication
 public:
     explicit ContactApplication(QObject *parent = nullptr);
 
-    QVector<KActionCollection *> actionCollections() const override;
+    QList<KActionCollection *> actionCollections() const override;
 
     Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window);
 
