@@ -26,9 +26,11 @@ void MailApplication::setupActions()
     mCollection->readSettings();
 }
 
-QVector<KActionCollection *> MailApplication::actionCollections() const
+QList<KActionCollection *> MailApplication::actionCollections() const
 {
     return {
         mCollection,
     };
 }
+
+#include "moc_mailapplication.cpp"
