@@ -14,7 +14,7 @@ public:
         NameRole = Qt::UserRole,
         ValueRole,
     };
-    Q_ENUM(Roles);
+    Q_ENUM(Roles)
 
     enum Header {
         To,
@@ -23,9 +23,9 @@ public:
         CC,
         ReplyTo,
     };
-    Q_ENUM(Header);
+    Q_ENUM(Header)
 
-    MailHeaderModel(QObject *parent = nullptr);
+    explicit MailHeaderModel(QObject *parent = nullptr);
     ~MailHeaderModel() override = default;
 
     QVariant data(const QModelIndex &index, int role) const override;
@@ -40,4 +40,4 @@ private:
     };
 
     QList<HeaderItem> m_headers;
-};
\ No newline at end of file
+};
